@@ -1,5 +1,5 @@
 /* comm -- compare two sorted files line by line.
-   Copyright (C) 86, 90, 91, 1995-2000 Free Software Foundation, Inc.
+   Copyright (C) 86, 90, 91, 1995-2001 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "comm"
 
-#define AUTHORS "Richard Stallman and David MacKenzie"
+#define AUTHORS N_ ("Richard Stallman and David MacKenzie")
 
 /* Undefine, to avoid warning about redefinition on some systems.  */
 #undef min
@@ -76,15 +76,15 @@ usage (int status)
 Usage: %s [OPTION]... LEFT_FILE RIGHT_FILE\n\
 "),
 	      program_name);
-      printf (_("\
+      fputs (_("\
 Compare sorted files LEFT_FILE and RIGHT_FILE line by line.\n\
 \n\
   -1              suppress lines unique to left file\n\
   -2              suppress lines unique to right file\n\
-  -3              suppress lines unique to both files\n\
-      --help      display this help and exit\n\
-      --version   output version information and exit\n\
-"));
+  -3              suppress lines that appear in both files\n\
+"), stdout);
+      fputs (HELP_OPTION_DESCRIPTION, stdout);
+      fputs (VERSION_OPTION_DESCRIPTION, stdout);
       puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
